/**

  The Initial Developer of the Original Code is
  Matthieu  - http://www.actionscript-facile.com
  Portions created by the Initial Developer are Copyright (C) 2010
  the Initial Developer. All Rights Reserved.

  Contributor(s) :

 */
package afterburner.view.game.engine.elements
{
	import starling.display.DisplayObjectContainer;
	import starling.core.Starling;
	import starling.display.MovieClip;
	import starling.textures.Texture;	
	
	
	import flash.geom.Point;

	
	import afterburner.view.util.MathUtils;


	/**
	 * Gestion des caractéristiques d'une balle.
	 * 
	 */
	public class Rocket
	{
		private var oMovie:MovieClip = null;
		private var content:DisplayObjectContainer;

		private var aParticules:Vector.<Smoke>;// contient une référence de tous les ennemis.
						
		private var acceleration : Point;
		private var speed : Point;
		private var rotation : Number;
		private var turn : Number;
		private var count : Number;
		private var engineCountdown : int;
		
				
				
				
		/**
		 * Constructeur.
		 * Ajoute un ennemi positionné aléatoirement.
		 * 
		 */
		public function Rocket(frames:Vector.<Texture>, name:String, x:Number = 0, y:Number = 0)
		{
			this.init(frames, name, x , y);
		}
		
		
		/**
		 * Init de la création de l'ennemi.
		 * 
		 */
		private function init(frames:Vector.<Texture>, name:String, x:Number = 0, y:Number = 0) : void
		{
			aParticules = new Vector.<Smoke>();
			
			/* init de l'ennemis */
			oMovie = new MovieClip(frames, 60);
			oMovie.name = name;
			Starling.juggler.add ( oMovie );
			
			oMovie.x = x;
			oMovie.y = y;
			
			acceleration = new Point();
			speed = new Point();
			rotation = Math.PI;
			
			acceleration.y = -2;
			speed.y = 5 + Math.random() * 5;
			
			turn = MathUtils.randomNumber(-0.01, 0.01);
			count = 0 ;
			speed.x = 5*MathUtils.randomInt(1, 10)/5 * MathUtils.randomPlusMinus();
			engineCountdown = 10;
		}
		
		
		
		/**
		 * Ajoute de la fumée derrière le missile.
		 * 
		 */
		public function addSmoke(frames:Vector.<Texture>, display:DisplayObjectContainer) : void
		{
			content = display;	
			
			var oSmoke : Smoke;
			for (var i : int = 0; i < 10; i++)
			{
				oSmoke = new Smoke(frames, oMovie.x - oMovie.width/2, oMovie.y + oMovie.height);
				content.addChild(oSmoke.clip);
				aParticules.push(oSmoke);
			}
			
		}


		/**
		 * Renvoie le clip pour ajout sur la scène
		 */
		public function get clip() : MovieClip {return oMovie;}
		
		
		
		/**
		 * Mise à jour du mouvement de l'ennemis.
		 * 
		 */
		public function update() : void
		{
			if(engineCountdown == 0)
			{
				count += 0.4;
				speed.y += acceleration.y;
			}
			else
			{
				rotation += turn;
				oMovie.rotation = -rotation-Math.PI;;
				acceleration.x = Math.sin(rotation) * 2;
				acceleration.y = Math.cos(rotation) * 2;
				engineCountdown--;
			}
			
			speed.x += acceleration.x;
			
			speed.x *= 0.95;
			oMovie.x += speed.x;
			oMovie.y += speed.y;
			
			var oSmoke:Smoke;
			for (var i : int = 0; i < aParticules.length; i++)
			{
				oSmoke = aParticules[i];
				oSmoke.update(oMovie.x - oMovie.width/2, oMovie.y + oMovie.height);	
			}
			
		}

		
		/**
		 * Supprime les ressources graphiques utilisées par l'ennemis.
		 * 
		 */
		private function remove() : void
		{
			if( oMovie != null )
			{
				Starling.juggler.remove ( oMovie );
				oMovie.removeFromParent(true);
				oMovie = null; 
				
				var oSmoke:Smoke;
				for (var i : int = 0; i < aParticules.length; i++)
				{
					oSmoke = aParticules[i];
					oSmoke.clip.removeFromParent(true);
					oSmoke = null;
				}
				
			}
			
		}


		/**
		 * Supprime les ressources utilisées par l'ennemis.
		 * 
		 */
		public function dispose() : void
		{
			this.remove();
		}
		
	}
}