/**

  The Initial Developer of the Original Code is
  Matthieu  - http://www.actionscript-facile.com
  Portions created by the Initial Developer are Copyright (C) 2010
  the Initial Developer. All Rights Reserved.

  Contributor(s) :

 */
package afterburner.view.game.stage3D
{
	
	
	import afterburner.view.ViewList;
	import afterburner.view.game.engine.elements.Ennemis;
	import afterburner.view.util.MathUtils;
	import flash.display.DisplayObject;
	import net.pixlib.events.PXObjectEvent;
	import net.pixlib.plugin.PXPlugin;
	import net.pixlib.view.PXContainerView;
	import starling.core.Starling;
	import starling.display.DisplayObjectContainer;
	import starling.display.Stage;
	import starling.events.Event;
	import starling.textures.Texture;
	import starling.textures.TextureAtlas;

	
	



	
	

	/**
	 * Utilisation du Framework 2D Starling.
	 * 
	 */
	public class EnnemisManager extends PXContainerView
	{
		private var aEnnemis:Vector.<Ennemis>;// contient une référence de tous les ennemis.
		
		private var oDisplay : DisplayObjectContainer;// le contenu Stage3D		
			
		/* gestion des textures */
		private var framesEnnemi:Vector.<Texture>;	
				
		public function EnnemisManager(owner : PXPlugin = null, mc : DisplayObject = null)
		{
			super(owner, ViewList.STAGE_3D_ENNEMIS, mc);
		}


		
		/**
		 * Methode appelez après l'instanciation d'une abstractUI
		 */
		override protected function onInitView() : void
		{
			//hide();
			show();
		}
		
		
		public function setDisplay3D(display:DisplayObjectContainer, sTextureAtlas : TextureAtlas) : void
		{
			oDisplay = display;
			
			aEnnemis = new Vector.<Ennemis>();
			
			framesEnnemi = sTextureAtlas.getTextures("ennemis");
		}


		/**
		 * Enlève tous les ennemis présents sur le jeu.
		 * 
		 */
		public function onStartGame() : void
		{
			var oEnnemis:Ennemis;
			
			for (var i : int = 0; i < aEnnemis.length; i++) 
			{
				oEnnemis = aEnnemis[i];
				this.disposeEnnemi(oEnnemis);
			}
			aEnnemis = new Vector.<Ennemis>();
		}


		
		/**
		 * Renvoie tous les missiles affichés sur le jeu.
		 * 
		 */
		public function getAllEnnemis() : Vector.<Ennemis>
		{
			return aEnnemis;
		}
		
		
		/**
		 * Mise à jour toutes les images pour effectuer le défilement du décor.
		 * 
		 */
		public function update(event:Event) : void
		{
			var oEnnemis:Ennemis;
			
			for (var i : int = 0; i < aEnnemis.length; i++) 
			{
				oEnnemis = aEnnemis[i];
				oEnnemis.update();
			
				// si l'ennemis sort du jeu --> suppression
				if( oEnnemis.clip.y > Stage(event.target).stageHeight)
				{
					aEnnemis.splice(i, 1);// enlève l'ennemi du tableau
					this.disposeEnnemi(oEnnemis);
				}
			}
			
			// ajoute aléatoirement 1 ou plusieurs ennemis -- ou si il reste peu d'ennemis sur le jeu
			if( ( MathUtils.randomInt(0, 13) == 1 || aEnnemis.length < 6 ) && aEnnemis.length < 233 )
				this.addEnnemis( MathUtils.randomInt(0, 5) );// ajoute des ennemis nombre aléatoirement*/
				
			/*if( (  aEnnemis.length < 2 ) && aEnnemis.length < 233 )
				this.addEnnemis( MathUtils.randomInt(0, 1) );// ajoute des ennemis nombre aléatoirement*/
		}
		
				
		
		/**
		 * Appel par un évènement CollisionModel.
		 * 
		 */
		public function onHitEnnemiLazer(event : PXObjectEvent) : void
		{
			//logger.debug(" ennemi manager onHitEnnemiRocket : "+event.value, this);

			this.removeEnnemi( event.value.ennemi as Ennemis );
		}	
		
		
		/**
		 * Appel par un évènement CollisionModel.
		 * 
		 */
		public function onHitEnnemiRocket(event : PXObjectEvent) : void
		{
			//logger.debug(" ennemi manager onHitEnnemiRocket : "+event.value, this);

			this.removeEnnemi( event.value.ennemi as Ennemis );
		}	
		
		/**
		 * Supprime un missile de l'écran.
		 * 
		 */
		public function removeEnnemi(ennemi:Ennemis) : void
		{
			var oEnnemis:Ennemis;
			
			for (var i : int = 0; i < aEnnemis.length; i++) 
			{
				oEnnemis = aEnnemis[i];
			
				// si le missile sort du jeu --> suppression
				if( oEnnemis == ennemi)
				{
					aEnnemis.splice(i, 1);// enlève l'ennemi du tableau
					this.disposeEnnemi(oEnnemis);
				}
			}
			
		}
			
		
		/**
		 * Ajoute des ennemis sur le jeu.
		 * @param nValue : le nombre d'ennemis à ajouter.
		 * 
		 */
		private function addEnnemis(nValue : int) : void
		{
			//PXQuick.debug("EnnemisManager addEnnemis : "+nValue, this);
			var oEnnemis:Ennemis;
			
			// ajout des ennemis sur la carte
			for (var i : int = 0; i < nValue; i++)
			{
				oEnnemis = new Ennemis(framesEnnemi, "ennemis", Starling.current.stage.stageWidth);
				oDisplay.addChild(oEnnemis.clip);	
				aEnnemis.push(oEnnemis);
			}
		}
		
		
		/**
		 * Supprime un missile de l'écran.
		 * 
		 * 
		 */
		private function disposeEnnemi(ennemi:Ennemis) : void
		{
			ennemi.dispose();	
		}
	
		
		
	}
}