/*
 * Copyright the original author or authors.
 * 
 * Licensed under the MOZILLA PUBLIC LICENSE, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.mozilla.org/MPL/MPL-1.1.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.pixlib.encoding 
{
	import net.pixlib.exceptions.PXIllegalArgumentException;
	import net.pixlib.log.PXStringifier;

	import flash.display.Shader;
	import flash.utils.ByteArray;

	/**
	 * The PXShaderDeserializer class deserialize content to build 
	 * DisplayObject instance.
	 * 
	 * @langversion 3.0
	 * @playerversion Flash 10
	 * 
	 * @author Romain Ecarnot
	 */
	final public class PXShaderDeserializer implements PXDeserializer
	{
		//--------------------------------------------------------------------
		// Public API
		//--------------------------------------------------------------------
		
		/**
		 * Creates instance.
		 * 
		 * @langversion 3.0
		 * @playerversion Flash 10
		 */		
		public function PXShaderDeserializer()
		{
		}

		/**
		 * Deserializes passed-in serializedContent and returns a Shader instance 
		 * using deserialization result.
		 * 
		 * @param serializedContent Content to deserialize (ByteArray object)
		 * @param target			(optional) Object to store deserialization 
		 * 							result.
		 * @param key				(optional) Registration identifier
		 * 
		 * @return serializedContent as a Shader instance if deserialization 
		 * process is success.
		 * 
		 * @throws	net.pixlib.exceptions.PXIllegalArgumentException The serializedContent 
		 * 			is not a compliant ByteArray source.
		 * 			
		 * @langversion 3.0
		 * @playerversion Flash 10
		 */
		public function deserialize(serializedContent : Object, target : Object = null, key : String = null ) : Object
		{
			try
			{
				var bytes : ByteArray = serializedContent as ByteArray;
				var shader : Shader = new Shader(bytes);
				
				return shader;
			}
			catch( e : Error )
			{
				throw new PXIllegalArgumentException("deserialize() error. Content is not Shader compliant", this);
			}
			
			return null;
		}

		/**
		 * Returns string represenation.
		 * 
		 * @langversion 3.0
		 * @playerversion Flash 10
		 */
		public function toString() : String 
		{
			return PXStringifier.process(this);
		}
	}
}
